var classtvg_1_1Scene =
[
    [ "clear", "classtvg_1_1Scene.html#ac020ea777be697067c6f5c8b18f6a4ed", null ],
    [ "paints", "classtvg_1_1Scene.html#ace6c268f853a4c144076de89b7bbbe75", null ],
    [ "push", "classtvg_1_1Scene.html#a8c4d96805c51d1e1876458ad84708925", null ],
    [ "push", "classtvg_1_1Scene.html#a19240cd5b53571da718fabef8afb7103", null ],
    [ "type", "classtvg_1_1Scene.html#a0998d9f221df277cafde4934e3828aa2", null ]
];